@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: client.c,v 1.67 2006/08/14 20:20:11 evertonm Exp $ */
+/* $Id: client.c,v 1.68 2007/03/22 21:56:53 evertonm Exp $ */
 
 #include <stdio.h>
 #include <sys/types.h>
@@ -440,6 +440,8 @@ static int greet(int sd)
   opt.write_delay             = nepim_global.write_delay;
   opt.keepalive_must_send     = nepim_global.tcp_keepalive_require;
   opt.keepalive_require       = nepim_global.tcp_keepalive_must_send;
+  opt.keepalive_timeout       = nepim_global.tcp_keepalive_recv_timer;
+  opt.keepalive_send_delay    = nepim_global.tcp_keepalive_send_delay;
   opt.seed                    = nepim_global.seed;
   opt.verify_data             = nepim_global.verify_data;
   opt.random_fill             = nepim_global.random_fill;
@@ -559,13 +561,20 @@ static void *on_tcp_keepalive_time(oop_source *src, struct timeval tv, void *use
   assert(!session->must_send);
   assert(session->keepalive_must_send);
 
+#ifdef NEPIM_DEBUG_KEEPALIVE
+  fprintf(stderr,
+          "NEPIM_DEBUG_KEEPALIVE %s %s: keepalive_send_delay=%ld\n",
+          __FILE__, __PRETTY_FUNCTION__,
+          session->keepalive_send_delay);
+#endif
+
   /* save next scheduling time */
   {
     int result = gettimeofday(&session->tv_keepalive_send_next, 0);
     assert(!result);
   }
   nepim_timer_usec_add(&session->tv_keepalive_send_next,
-		       nepim_global.tcp_keepalive_send_delay);
+                       session->keepalive_send_delay);
 
   /* start to write */
   nepim_global.oop_src->on_fd(nepim_global.oop_src, pipe->sd, OOP_WRITE,
@@ -955,6 +964,8 @@ static void spawn_one_tcp_client(const char *hostport,
       opt.write_delay             = nepim_global.write_delay;
       opt.keepalive_must_send     = nepim_global.tcp_keepalive_require;
       opt.keepalive_require       = nepim_global.tcp_keepalive_must_send;
+      opt.keepalive_timeout       = nepim_global.tcp_keepalive_recv_timer;
+      opt.keepalive_send_delay    = nepim_global.tcp_keepalive_send_delay;
       opt.seed                    = nepim_global.seed;
       opt.verify_data             = nepim_global.verify_data;
       opt.random_fill             = nepim_global.random_fill;
