@@ -54,8 +54,8 @@ nepim_global_t nepim_global = {
   -1,       /* mcast_ttl */
   500000,   /* udp_greet_delay (usec) */
   5,        /* max_greetings */
-  2000000,  /* udp_keepalive_recv_timer (usec, receivers) */
-  500000,   /* udp_keepalive_send_delay (usec, non-senders) */
+  2000000,  /* udp_keepalive_recv_timer (usec, receivers, 2 sec) */
+  500000,   /* udp_keepalive_send_delay (usec, non-senders, .5 sec) */
   1,        /* udp_keepalive_require (boolean, receivers) */
   1,        /* udp_keepalive_must_send (boolean, non-senders) */
   4000,     /* udp_win_max */
@@ -74,8 +74,8 @@ nepim_global_t nepim_global = {
   -1,       /* debug_error_verbose (boolean) */
   -1,       /* ip tos (default: don't change) */
   1,        /* socket keepalive (client, boolean, -1 is don't change */
-  20000000, /* tcp_keepalive_recv_timer (usec, receivers, 60 sec) */
-  10000000, /* tcp_keepalive_send_delay (usec, non-senders, 20 sec) */
+  20000000, /* tcp_keepalive_recv_timer (usec, receivers, 20 sec) */
+  10000000, /* tcp_keepalive_send_delay (usec, non-senders, 10 sec) */
   0,        /* tcp_keepalive_require (boolean, receivers) */
   0,        /* tcp_keepalive_must_send (boolean, non-senders) */
   -1,       /* nagle (client, boolean, -1 is don't change) */
