@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: greet.h,v 1.17 2006/06/05 15:52:01 evertonm Exp $ */
+/* $Id: greet.h,v 1.19 2007/03/23 12:40:05 evertonm Exp $ */
 
 #ifndef NEPIM_GREET_H
 #define NEPIM_GREET_H
@@ -34,6 +34,8 @@ struct nepim_greet_t {
   long           write_delay;
   int            keepalive_must_send;
   int            keepalive_require;
+  int            keepalive_timeout;
+  int            keepalive_send_delay;
   unsigned       seed;
   unsigned       verify_data;
   int            random_fill;
@@ -53,7 +55,7 @@ struct nepim_greet_t {
 int nepim_write_greetings(const nepim_greet_t *opt, char *buf,
                           int buf_size);
 
-int nepim_parse_greetings(nepim_greet_t *opt, 
+int nepim_parse_greetings(nepim_greet_t *opt, int is_tcp,
                           const char *buf, const char *past_end);
 
 #endif /* NEPIM_GREET_H */
