@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: server.c,v 1.77 2006/08/14 20:20:11 evertonm Exp $ */
+/* $Id: server.c,v 1.79 2007/03/23 12:40:05 evertonm Exp $ */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -423,21 +423,22 @@ static int parse_greetings(int sd,
   opt.password_buf = password_buf;
   opt.password_buf_size = sizeof(password_buf);
 
-  result = nepim_parse_greetings(&opt, buf, past_end);
+  result = nepim_parse_greetings(&opt, 1 /* is_tcp=true */, buf, past_end);
   if (result)
     return result;
 
   fprintf(stderr, 
           "%d: send=%d bit_rate=%lld pkt_rate=%d "
-          "interval=%d duration=%d delay=%ld ka_send=%d ka_req=%d seed=0x%08x "
-          "verify_data=%d random_fill=%d fill_byte=0x%02x pause_duration=%d "
+          "interval=%d duration=%d delay=%ld ka_send=%d ka_req=%d ka_tmout=%d ka_delay=%d "
+          "seed=0x%08x verify_data=%d random_fill=%d fill_byte=0x%02x pause_duration=%d "
           "sock_ka=%d nagle=%d overhead=%d "
 	  "sweep_random=%d sweep_step=%d write_floor=%d write_ceil=%d "
 	  "password=%s\n", 
           sd, opt.must_send, opt.bit_rate, opt.pkt_rate,
           opt.stat_interval, opt.test_duration, 
           opt.write_delay, opt.keepalive_must_send,
-          opt.keepalive_require, opt.seed,
+          opt.keepalive_require, opt.keepalive_timeout, opt.keepalive_send_delay,
+          opt.seed,
           opt.verify_data, opt.random_fill, opt.fill_byte, opt.pause_duration,
 	  opt.socket_keepalive, opt.nagle, opt.overhead,
 	  opt.sweep_random, opt.sweep_step, opt.write_floor, opt.write_ceil,
@@ -637,13 +638,20 @@ static void *on_tcp_keepalive_time(oop_source *src, struct timeval tv, void *use
   assert(!session->must_send);
   assert(session->keepalive_must_send);
 
+#ifdef NEPIM_DEBUG_KEEPALIVE
+  fprintf(stderr,
+          "NEPIM_DEBUG_KEEPALIVE %s %s: keepalive_send_delay=%ld\n",
+          __FILE__, __PRETTY_FUNCTION__,
+          session->keepalive_send_delay);
+#endif
+
   /* save next scheduling time */
   {
     int result = gettimeofday(&session->tv_keepalive_send_next, 0);
     assert(!result);
   }
   nepim_timer_usec_add(&session->tv_keepalive_send_next,
-		       nepim_global.tcp_keepalive_send_delay);
+		       session->keepalive_send_delay);
 
   /* start to write */
   nepim_global.oop_src->on_fd(nepim_global.oop_src, pipe->sd, OOP_WRITE,
