@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: session.c,v 1.15 2006/06/02 14:24:38 evertonm Exp $ */
+/* $Id: session.c,v 1.16 2007/03/22 21:56:53 evertonm Exp $ */
 
 #include <string.h>
 #include <assert.h>
@@ -55,6 +55,8 @@ void nepim_session_init(nepim_session_t *session, const nepim_greet_t *opt,
   session->write_delay             = opt->write_delay;
   session->keepalive_must_send     = opt->keepalive_must_send;
   session->keepalive_require       = opt->keepalive_require;
+  session->keepalive_timeout       = opt->keepalive_timeout;
+  session->keepalive_send_delay    = opt->keepalive_send_delay;
   session->seed                    = opt->seed;
   session->check_seed              = opt->seed;        /* see tcp_check_data() */
   session->verify_data             = opt->verify_data;
