@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: session.h,v 1.22 2006/06/02 14:24:38 evertonm Exp $ */
+/* $Id: session.h,v 1.23 2007/03/22 21:56:53 evertonm Exp $ */
 
 #ifndef NEPIM_SESSION_H
 #define NEPIM_SESSION_H
@@ -61,6 +61,8 @@ struct nepim_session_t {
   int duration_done;           /* boolean */
   int keepalive_must_send;     /* boolean, non-senders */
   int keepalive_require;       /* boolean, receivers */
+  susec_t keepalive_timeout;   /* usec, receivers */
+  susec_t keepalive_send_delay; /* usec, non-senders */
   int keepalives_recv;         /* counter, receivers */
   unsigned seed;
   unsigned check_seed;	       /* used only by tcp_check_data() */
