@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: slot.c,v 1.44 2006/06/05 15:52:01 evertonm Exp $ */
+/* $Id: slot.c,v 1.45 2007/03/22 21:56:53 evertonm Exp $ */
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -355,12 +355,19 @@ void nepim_schedule_keepalive_timer(nepim_slot_t *slot,
 
   assert(session->keepalive_require);
 
+#ifdef NEPIM_DEBUG_KEEPALIVE
+  fprintf(stderr,
+          "NEPIM_DEBUG_KEEPALIVE %s %s: keepalive_timeout=%ld\n",
+          __FILE__, __PRETTY_FUNCTION__,
+          session->keepalive_timeout);
+#endif
+
   {
     int result = gettimeofday(&session->tv_keepalive_recv_timer, 0);
     assert(!result);
   }
   nepim_timer_usec_add(&session->tv_keepalive_recv_timer, 
-                       nepim_global.udp_keepalive_recv_timer);
+                       session->keepalive_timeout);
 
   nepim_global.oop_src->on_time(nepim_global.oop_src,
                                 session->tv_keepalive_recv_timer,
