@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: udp_client.c,v 1.79 2006/08/15 13:20:33 evertonm Exp $ */
+/* $Id: udp_client.c,v 1.80 2007/03/22 21:56:53 evertonm Exp $ */
 
 #include <stdio.h>
 #include <string.h>
@@ -114,13 +114,20 @@ static void *on_udp_keepalive_time(oop_source *src, struct timeval tv, void *use
   assert(!session->must_send);
   assert(session->keepalive_must_send);
 
+#ifdef NEPIM_DEBUG_KEEPALIVE
+  fprintf(stderr,
+          "NEPIM_DEBUG_KEEPALIVE %s %s: keepalive_send_delay=%ld\n",
+          __FILE__, __PRETTY_FUNCTION__,
+          session->keepalive_send_delay);
+#endif
+
   /* save next scheduling time */
   {
     int result = gettimeofday(&session->tv_keepalive_send_next, 0);
     assert(!result);
   }
   nepim_timer_usec_add(&session->tv_keepalive_send_next,
-		       nepim_global.udp_keepalive_send_delay);
+		       session->keepalive_send_delay);
 
   /* start to write */
   nepim_will_slot_keepalive(slot, on_udp_write);
@@ -405,6 +412,8 @@ static int slot_greet_write(nepim_slot_t *slot)
   opt.write_delay             = nepim_global.write_delay;
   opt.keepalive_must_send     = nepim_global.udp_keepalive_require;
   opt.keepalive_require       = nepim_global.udp_keepalive_must_send;
+  opt.keepalive_timeout       = nepim_global.udp_keepalive_recv_timer;
+  opt.keepalive_send_delay    = nepim_global.udp_keepalive_send_delay;
   opt.seed                    = nepim_global.seed;
   opt.verify_data             = nepim_global.verify_data;
   opt.random_fill             = nepim_global.random_fill;
@@ -1404,6 +1413,8 @@ static void parse_hosts(const char *host_list)
       opt.write_delay             = nepim_global.write_delay;
       opt.keepalive_must_send     = nepim_global.udp_keepalive_must_send;
       opt.keepalive_require       = nepim_global.udp_keepalive_require;
+      opt.keepalive_timeout       = nepim_global.udp_keepalive_recv_timer;
+      opt.keepalive_send_delay    = nepim_global.udp_keepalive_send_delay;
       opt.seed                    = nepim_global.seed;
       opt.verify_data             = nepim_global.verify_data;
       opt.random_fill             = nepim_global.random_fill;
